@@ -15,6 +15,13 @@ fn main() {
         println!("Tracker: \"{}\".", context.tracker_name());
     }
 
+    let speed1 = context.playing_speed();
+    let speed2 = speed1;
+
+    if speed1 > speed2 {
+        println!("asd")
+    }
+
     let stream = device
         .build_output_stream(
             &config,
