@@ -62,7 +62,7 @@ impl Context {
     /// Creates a context directly from the raw pointer of another context.
     ///
     /// # Safety
-    /// Pointer must be previously allocated via [`new`] function or it's equivalent - [`xm_create_context_safe`].
+    /// `pointer` must be previously allocated via [`new`] function or it's equivalent - [`xm_create_context_safe`].
     ///
     /// [`new`]: Self::new
     /// [`xm_create_context_safe`]: xm_create_context_safe
@@ -310,14 +310,14 @@ impl Drop for Context {
 }
 
 /// Module playback speed.
-#[derive(Debug)]
+#[derive(Debug, PartialEq, Eq, PartialOrd, Ord, Clone, Copy)]
 pub struct Speed {
     pub bpm: u16,
     pub tempo: u16,
 }
 
 /// Module playback position.
-#[derive(Debug)]
+#[derive(Debug, PartialEq, Eq, PartialOrd, Ord, Clone, Copy)]
 pub struct Position {
     pub pattern_index: u8,
     pub pattern: u8,
@@ -326,7 +326,7 @@ pub struct Position {
 }
 
 /// Context creation error.
-#[derive(Debug)]
+#[derive(Debug, PartialEq, Eq, Clone, Copy)]
 pub enum ContextError {
     #[cfg(feature = "defensive")]
     /// Module sanity error.
@@ -337,7 +337,7 @@ pub enum ContextError {
 }
 
 /// Error of out of bounds.
-#[derive(Debug)]
+#[derive(Debug, PartialEq, Eq, Clone, Copy)]
 pub enum OutOfBoundsError {
     Patterns,
     Instruments,
